@@ -278,7 +278,7 @@ static KAboutData createAboutData()
          "okular_poppler",
          "okular_poppler",
          ki18n( "PDF Backend" ),
-         "0.4",
+         "0.4.1",
          ki18n( "A PDF file renderer" ),
          KAboutData::License_GPL,
          ki18n( "© 2005-2008 Albert Astals Cid" )
@@ -1117,17 +1117,13 @@ void PDFGenerator::addPages( KConfigDialog * )
 bool PDFGenerator::setDocumentRenderHints()
 {
     bool changed = false;
-    static Poppler::Document::RenderHints oldhints = 0;
+    const Poppler::Document::RenderHints oldhints = pdfdoc->renderHints();
 #define SET_HINT(hintname, hintdefvalue, hintflag) \
 { \
     bool newhint = documentMetaData(hintname, hintdefvalue).toBool(); \
     if (newhint != (oldhints & hintflag)) \
     { \
         pdfdoc->setRenderHint(hintflag, newhint); \
-        if (newhint) \
-            oldhints |= hintflag; \
-        else \
-            oldhints &= ~(int)hintflag; \
         changed = true; \
     } \
 }
